# aotycount

A small program to count the common albums in the album of the year lists recorded in [@hubgit]'s https://aoty.hubmed.org/. The basic, and perhaps flawed, idea is that the more lists an album is on, the higher priority I should give to checking it out, to see what all the fuss is about.

(Thanks for the lists [@hubgit]!)

```
uvx aotycount 2023

[14] Caroline Polachek - Desire, I Want To Turn Into You [Clash, The Fader, The Forty-Five, PopMatters, Pitchfork, Crack, The Line of Best Fit, Consequence, Louder Than War, Gorilla vs Bear, Exclaim, Paste, Piccadilly Records, Rough Trade]
[14] Sufjan Stevens - Javelin [Clash, The Fader, PopMatters, Pitchfork, The Line of Best Fit, Consequence, Gorilla vs Bear, Rolling Stone, Exclaim, Paste, Mojo, Uncut, Piccadilly Records, Rough Trade]
[14] Boygenius - The Record [Clash, The Forty-Five, Concrete Islands, PopMatters, Pitchfork, Crack, Consequence, Louder Than War, Rolling Stone, Exclaim, Paste, Mojo, Uncut, Piccadilly Records]
[12] Mitski - The Land Is Inhospitable And So Are We [Clash, The Fader, The Forty-Five, PopMatters, Pitchfork, The Line of Best Fit, Consequence, Rolling Stone, Exclaim, Paste, Mojo, Piccadilly Records]
[12] Olivia Rodrigo - GUTS [Clash, The Forty-Five, Concrete Islands, PopMatters, Pitchfork, The Line of Best Fit, Consequence, Louder Than War, Gorilla vs Bear, Rolling Stone, Exclaim, Paste]
[12] Kelela - Raven [Clash, The Fader, The Forty-Five, PopMatters, Pitchfork, Crack, The Line of Best Fit, Consequence, Rolling Stone, Exclaim, Paste, The Quietus]
[12] PJ Harvey - I Inside The Old Year Dying [Clash, Concrete Islands, Crack, The Line of Best Fit, Consequence, Fast 'n' Bulbous, Louder Than War, Paste, Mojo, Uncut, The Quietus, Piccadilly Records]
[12] Wednesday - Rat Saw God [Clash, The Fader, The Forty-Five, PopMatters, Pitchfork, The Line of Best Fit, Consequence, Rolling Stone, Exclaim, Paste, Uncut, Rough Trade]
[12] Noname - Sundial [Clash, The Fader, The Forty-Five, The Wire, PopMatters, Pitchfork, Crack, The Line of Best Fit, Consequence, Rolling Stone, Paste, The Quietus]
[9] Julie Byrne - The Greater Wings [Clash, The Fader, Pitchfork, The Line of Best Fit, Gorilla vs Bear, Exclaim, Paste, Mojo, Uncut]
[9] ANOHNI And The Johnsons - My Back Was A Bridge For You To Cross [Clash, The Wire, Pitchfork, Consequence, Rolling Stone, Paste, Mojo, Uncut, The Quietus]
[9] Lankum - False Lankum [Clash, Concrete Islands, Crack, The Line of Best Fit, Fast 'n' Bulbous, Louder Than War, Mojo, Uncut, The Quietus]
[9] Fever Ray - Radical Romantics [Clash, The Fader, The Wire, Pitchfork, Crack, The Line of Best Fit, Gorilla vs Bear, Exclaim, The Quietus]
[8] Amaarae - Fountain Baby [Clash, The Fader, The Forty-Five, Pitchfork, Crack, The Line of Best Fit, Rolling Stone, Exclaim]
[8] Young Fathers - Heavy Heavy [Clash, Concrete Islands, The Line of Best Fit, Consequence, Louder Than War, Paste, Mojo, Rough Trade]
[8] Kara Jackson - Why Does the Earth Give Us People to Love? [Clash, The Fader, Pitchfork, Crack, Consequence, Rolling Stone, Paste, Uncut]
[8] Slowdive - Everything Is Alive [Clash, PopMatters, The Line of Best Fit, Consequence, Louder Than War, Mojo, Uncut, Piccadilly Records]
[8] Yo La Tengo - This Stupid World [Rosy Overdrive, The Wire, Pitchfork, Louder Than War, Rolling Stone, Paste, Mojo, Uncut]
[7] Laurel Halo - Atlas [Clash, The Fader, PopMatters, Pitchfork, Crack, Gorilla vs Bear, Exclaim]
[7] Armand Hammer - We Buy Diabetic Test Strips [Clash, PopMatters, Crack, Cabbages, Gorilla vs Bear, Paste, Rough Trade]
[7] Sofia Kourtesis - Madres [Clash, PopMatters, Pitchfork, Gorilla vs Bear, Exclaim, Paste, Piccadilly Records]
[7] Blur - The Ballad Of Darren [Clash, Concrete Islands, Louder Than War, Rolling Stone, Mojo, Uncut, Piccadilly Records]
[7] Paramore - This Is Why [Clash, The Forty-Five, Kerrang!, PopMatters, Rolling Stone, Exclaim, Piccadilly Records]
[7] Lana Del Rey - Did You Know That There's A Tunnel Under Ocean Blvd [The Fader, The Forty-Five, Crack, Gorilla vs Bear, Rolling Stone, Exclaim, Piccadilly Records]
[7] Blondshell - Blondshell [The Forty-Five, PopMatters, Crack, The Line of Best Fit, Consequence, Rolling Stone, Rough Trade]
[7] Grian Chatten - Chaos For the Fly [Concrete Islands, The Line of Best Fit, Louder Than War, Mojo, Uncut, Piccadilly Records, Rough Trade]
[6] Yaeji - With A Hammer [Clash, The Forty-Five, PopMatters, Pitchfork, The Line of Best Fit, The Quietus]
[6] Jessie Ware - That! Feels Good! [Clash, PopMatters, Pitchfork, Consequence, Paste, Piccadilly Records]
[6] Tomb Mold - The Enduring Spirit [Metal Hammer (Readers Poll), PopMatters, Pitchfork, Fast 'n' Bulbous, Exclaim, Decibel]
[6] Billy Woods & Kenny Segal - Maps [The Fader, The Wire, Consequence, Paste, Mojo, The Quietus]
[6] Yeule - Softscars [The Fader, Pitchfork, The Line of Best Fit, Consequence, Paste, Piccadilly Records]
[6] Lana Del Rey - Did you know that there’s a tunnel under Ocean Blvd [Concrete Islands, Pitchfork, Consequence, Paste, Mojo, Uncut]
[6] Jason Isbell and the 400 Unit - Weathervanes [Rosy Overdrive, Consequence, Rolling Stone, Paste, Mojo, Uncut]
[5] King Krule - Space Heavy [Clash, PopMatters, Gorilla vs Bear, Mojo, Piccadilly Records]
[5] Yussef Dayes - Black Classical Music [Clash, Concrete Islands, PopMatters, Piccadilly Records, Rough Trade]
[5] Asake - Work of Art [Clash, The Fader, Crack, Consequence, Rolling Stone]
[5] Metallica - 72 Seasons [Metal Hammer (Readers Poll), Kerrang!, Consequence, Revolver, Rolling Stone]
[5] Baroness - Stone [Metal Hammer (Readers Poll), Kerrang!, Consequence, Revolver, Fast 'n' Bulbous]
[5] Reverend Kristin Michael Hayter - SAVED! [The Fader, Kerrang!, PopMatters, Paste, The Quietus]
[5] 100 Gecs - 10,000 Gecs [The Fader, Kerrang!, Pitchfork, Rolling Stone, Exclaim]
[5] jaimie branch - Fly or Die Fly or Die Fly or Die ((world war)) [The Fader, The Wire, Pitchfork, Mojo, Uncut]
[5] Nourished By Time - Erotic Probiotic 2 [The Fader, Pitchfork, Gorilla vs Bear, Paste, Piccadilly Records]
[5] Ratboys - The Window [PopMatters, The Line of Best Fit, Consequence, Exclaim, Paste]
[5] Depeche Mode - Memento Mori [PopMatters, Louder Than War, Rolling Stone, Mojo, Uncut]
[5] Everything But The Girl - Fuse [Louder Than War, Rolling Stone, Mojo, Uncut, Rough Trade]
[4] Sampha - Lahai [Clash, PopMatters, The Line of Best Fit, Rolling Stone]
[4] billy woods and Kenny Segal - Maps [Clash, The Line of Best Fit, Rolling Stone, Exclaim]
[4] L’Rain - I Killed Your Dog [Clash, Pitchfork, Consequence, Paste]
[4] Bar Italia - Tracey Denim [Clash, The Fader, Mojo, Piccadilly Records]
[4] Troye Sivan - Something to Give Each Other [Clash, Crack, Consequence, Rolling Stone]
[4] Nation of Language - Strange Disciple [Clash, PopMatters, Paste, Rough Trade]
[4] Yves Tumor - Praise a Lord Who Chews But Which Does Not Consume; (Or Simply, Hot Between Worlds) [The Fader, Pitchfork, Exclaim, Paste]
[4] Kali Uchis - Red Moon in Venus [The Fader, The Forty-Five, Pitchfork, Rolling Stone]
[4] Corinne Bailey Rae - Black Rainbows [The Forty-Five, Mojo, Uncut, Piccadilly Records]
[4] Militarie Gun - Life Under the Gun [Kerrang!, The Line of Best Fit, Rolling Stone, Exclaim]
[4] Sweeping Promises - Good Living Is Coming For You [Concrete Islands, Pitchfork, Exclaim, Paste]
[4] The Tubs - Dead Meat [Rosy Overdrive, Fast 'n' Bulbous, Mojo, Piccadilly Records]
[4] Animal Collective - Isn’t It Now? [The Wire, PopMatters, Mojo, Uncut]
[4] James Holden - Imagine This Is A High Dimensional Space Of All Possibilities [The Wire, Mojo, The Quietus, Piccadilly Records]
[4] Water From Your Eyes - Everyone’s Crushed [PopMatters, Pitchfork, Consequence, Paste]
[4] Avalon Emerson - & the Charm [Pitchfork, Crack, Gorilla vs Bear, Exclaim]
[4] Lonnie Holley - Oh Me Oh My [Pitchfork, Paste, Mojo, Uncut]
[4] Mandy, Indiana - i've seen a way [Crack, Piccadilly Records, Rough Trade, Rough Trade]
[4] L'Rain - I Killed Your Dog [Crack, The Line of Best Fit, Rolling Stone, The Quietus]
[4] The Coral - Sea Of Mirrors [Fast 'n' Bulbous, Mojo, Uncut, Piccadilly Records]
[4] OSEES - Intercepted Message [Louder Than War, Mojo, Uncut, Piccadilly Records]
[4] Wilco - Cousin [Louder Than War, Rolling Stone, Mojo, Uncut]
[4] Sleaford Mods - UK GRIM [Louder Than War, Mojo, Uncut, The Quietus]
[4] Sparks - The Girl Is Crying In Her Latte [Louder Than War, Mojo, Uncut, The Quietus]
[3] Loraine James - Gentle Confrontation [Clash, PopMatters, Exclaim]
[3] Liv.e - Girl in the Half Pearl [Clash, The Forty-Five, Pitchfork]
[3] CMAT - Crazymad, For Me [Clash, The Forty-Five, Louder Than War]
[3] ML Buch - Suntub [Clash, Gorilla vs Bear, Exclaim]
[3] Sleep Token - Take Me Back to Eden [Metal Hammer (Readers Poll), Kerrang!, Revolver]
[3] Babymetal - The Other One [Metal Hammer (Readers Poll), Kerrang!, Revolver]
[3] Blackbraid - Blackbraid II [Metal Hammer (Readers Poll), Revolver, Decibel]
[3] Green Lung - This Heathen Land [Metal Hammer (Readers Poll), Kerrang!, Fast 'n' Bulbous]
[3] Dying Wish - Symptoms of Survival [Metal Hammer (Readers Poll), Kerrang!, Revolver]
[3] a.s.o. - a.s.o. [The Fader, Crack, Gorilla vs Bear]
[3] Veeze - Ganger [The Fader, Pitchfork, Rolling Stone]
[3] SZA - SOS [The Fader, Pitchfork, Rolling Stone]
[3] Samia - Honey [The Fader, The Forty-Five, The Line of Best Fit]
[3] Indigo De Souza - All of This Will End [The Forty-Five, Consequence, Paste]
[3] Arlo Parks - My Soft Machine [The Forty-Five, Rolling Stone, Piccadilly Records]
[3] Water From Your Eyes - Everyone's Crushed [The Forty-Five, Crack, Rolling Stone]
[3] Jorja Smith - Falling or Flying [The Forty-Five, PopMatters, Rolling Stone]
[3] Bully - Lucky For You [The Forty-Five, Rolling Stone, Paste]
[3] Foo Fighters - But Here We Are [Kerrang!, Consequence, Piccadilly Records]
[3] Gel - Only Constant [Kerrang!, Louder Than War, Decibel]
[3] HEALTH - RAT WARS [Kerrang!, Revolver, Exclaim]
[3] Sparklehorse - Bird Machine [Rosy Overdrive, Louder Than War, Piccadilly Records]
[3] The Mountain Goats - Jenny from Thebes [Rosy Overdrive, PopMatters, Paste]
[3] The Clientele - I Am Not There Anymore [The Wire, PopMatters, Uncut]
[3] Ryuichi Sakamoto - 12 [The Wire, Pitchfork, Uncut]
[3] Mozart Estate - Pop-Up! Ker-Ching! And The Possibilities Of Modern Shopping [The Wire, Mojo, The Quietus]
[3] The Necks - Travel [The Wire, Mojo, Uncut]
[3] Jungle - Volcano [PopMatters, Rolling Stone, Piccadilly Records]
[3] Fatoumata Diawara - London Ko [PopMatters, Mojo, Uncut]
[3] Joy Oladokun - Proof of Life [PopMatters, Consequence, Rolling Stone]
[3] Algiers - Shook [PopMatters, Louder Than War, The Quietus]
[3] Niecy Blues - Exit Simulation [PopMatters, Gorilla vs Bear, The Quietus]
[3] Sunny War - Anarchist Gospel [PopMatters, Louder Than War, Uncut]
[3] Jamila Woods - Water Made Us [PopMatters, Consequence, Rolling Stone]
[3] NewJeans - Get Up [PopMatters, Gorilla vs Bear, Rolling Stone]
[3] Model/Actriz - Dogsbody [Pitchfork, Rolling Stone, Exclaim]
[3] Jess Williamson - Time Ain’t Accidental [Pitchfork, The Line of Best Fit, Paste]
[3] JPEGMAFIA & Danny Brown - SCARING THE HOES [Crack, Consequence, Paste]
[3] McKinley Dixon - Beloved! Paradise! Jazz!? [The Line of Best Fit, Rolling Stone, Paste]
[3] Benefits - Nails [The Line of Best Fit, Louder Than War, The Quietus]
[3] Janelle Monáe - The Age of Pleasure [Consequence, Rolling Stone, Mojo]
[3] Godflesh - Purge [Fast 'n' Bulbous, Rolling Stone, The Quietus]
[3] Pigs Pigs Pigs Pigs Pigs Pigs Pigs - Land Of Sleeper [Louder Than War, The Quietus, Piccadilly Records]
[3] BC Camplight - The Last Rotation Of Earth [Mojo, Uncut, Piccadilly Records]
[3] Teenage Fanclub - Nothing Lasts Forever [Mojo, Uncut, Piccadilly Records]
[3] Shirley Collins - Archangel Hill [Mojo, Uncut, The Quietus]
[3] Eddie Chacon - Sundown [Mojo, Uncut, Piccadilly Records]
[2] Earl Sweatshirt and the Alchemist - VOIR DIRE [Clash, Exclaim]
[2] CASISDEAD - Famous Last Words [Clash, The Line of Best Fit]
[2] Cleo Sol - Heaven [Clash, The Fader]
[2] Christine and the Queens - Paranoïa, Angels, True Love [Clash, Rolling Stone]
[2] JESSY LANZA - Love Hallucination [Clash, Gorilla vs Bear]
[2] Overmono - Good Lies [Clash, Piccadilly Records]
[2] Doja Cat - Scarlet [Clash, The Forty-Five]
[2] Victoria Monét - Jaguar II [Clash, Rolling Stone]
[2] Romy - Mid Air [Clash, Piccadilly Records]
[2] Speakers Corner Quartet - Further Out Than the Edge [Clash, Crack]
[2] Jonah Yano - portrait of a dog [Clash, Exclaim]
[2] Ice Spice - Like..? [Clash, Rolling Stone]
[2] Within Temptation - Bleed Out [Metal Hammer (Readers Poll), Kerrang!]
[2] Cattle Decapitation - Terrasite [Metal Hammer (Readers Poll), Decibel]
[2] Avenged Sevenfold - Life Is but a Dream... [Metal Hammer (Readers Poll), Revolver]
[2] Voice Of Baceprot - Retas [Metal Hammer (Readers Poll), Kerrang!]
[2] In Flames - Foregone [Metal Hammer (Readers Poll), Revolver]
[2] Orbit Culture - Descent [Metal Hammer (Readers Poll), Revolver]
[2] Dying Fetus - Make Them Beg for Death [Metal Hammer (Readers Poll), Revolver]
[2] Silent Planet - Superbloom [Metal Hammer (Readers Poll), Revolver]
[2] VV - Neon Noir [Metal Hammer (Readers Poll), Kerrang!]
[2] Cannibal Corpse - Chaos Horrific [Metal Hammer (Readers Poll), Decibel]
[2] Obituary - Dying of Everything [Metal Hammer (Readers Poll), Decibel]
[2] Periphery - Periphery V: Djent Is Not a Genre [Metal Hammer (Readers Poll), Revolver]
[2] Therapy? - Hard Cold Fire [Metal Hammer (Readers Poll), Louder Than War]
[2] Beartooth - The Surface [Metal Hammer (Readers Poll), Kerrang!]
[2] Enslaved - Heimdal [Metal Hammer (Readers Poll), Decibel]
[2] Svalbard - The Weight Of The Mask [Metal Hammer (Readers Poll), Kerrang!]
[2] HiTech - Détwat [The Fader, Pitchfork]
[2] Sexyy Red - Hood Hottest Princess [The Fader, Pitchfork]
[2] The Armed - Perfect Saviors [The Fader, Kerrang!]
[2] Maria BC - Spike Field [The Fader, Paste]
[2] John Francis Flynn - Look Over The Wall, See The Sky [The Fader, The Quietus]
[2] Gia Margaret - Romantic Piano [The Fader, PopMatters]
[2] JIM LEGXACY - hnpm [The Fader, Gorilla vs Bear]
[2] MIKE - Burning Desire [The Fader, Exclaim]
[2] Kara Jackson - Why Does the Earth Give Us People to Love [The Forty-Five, The Line of Best Fit]
[2] Jessie Ware - That! Feels! Good! [The Forty-Five, Rolling Stone]
[2] Olivia Dean - Messy [The Forty-Five, The Line of Best Fit]
[2] Holly Humberstone - Paint My Bedroom Black [The Forty-Five, Rolling Stone]
[2] Raye - My 21st Century Blues [The Forty-Five, Consequence]
[2] Jesus Piece - …So Unknown [Kerrang!, Decibel]
[2] Drain - Living Proof [Kerrang!, Revolver]
[2] Code Orange - The Above [Kerrang!, Revolver]
[2] Zulu - A New Tomorrow [Kerrang!, Crack]
[2] Fucked Up - One Day [Kerrang!, PopMatters]
[2] Poppy - Zig [Kerrang!, Revolver]
[2] Queens Of The Stone Age - In Times New Roman… [Kerrang!, Fast 'n' Bulbous]
[2] Madder Rose - No One Gets Hurt Ever [Concrete Islands, Rosy Overdrive]
[2] Meg Baird - Furling [Concrete Islands, Uncut]
[2] Apostille - Prisoners Of Love And Hate [Concrete Islands, The Quietus]
[2] Holy Tongue - Deliverance and Spiritual Warfare [Concrete Islands, Crack]
[2] Slow Pulp - Yard [Concrete Islands, Paste]
[2] Upper Wilds - Jupiter [Rosy Overdrive, PopMatters]
[2] Patio - Collection [Rosy Overdrive, Fast 'n' Bulbous]
[2] Greg Mendez - Greg Mendez [Rosy Overdrive, Paste]
[2] Eyelids - A Colossal Waste of Light [Rosy Overdrive, Fast 'n' Bulbous]
[2] Philip Jeck & Chris Watson - Oxmardyke [The Wire, The Quietus]
[2] Khanate - To Be Cruel [The Wire, The Quietus]
[2] Matana Roberts - Coin Coin Chapter Five: In The Garden [The Wire, The Quietus]
[2] Mariam Rezaei - BOWN [The Wire, The Quietus]
[2] Irreversible Entanglements - Protect Your Light [The Wire, Mojo]
[2] Raphael Rogiński - Talàn [The Wire, The Quietus]
[2] Ruth Anderson & Annea Lockwood - Tête-à-tête [The Wire, The Quietus]
[2] Aho Ssan - Rhizomes [The Wire, The Quietus]
[2] Bill Orcutt - The Anxiety Of Symmetry [The Wire, The Quietus]
[2] PATTEN - Mirage FM [The Wire, Gorilla vs Bear]
[2] Beach Fossils - Bunny [PopMatters, Piccadilly Records]
[2] Kylie Minogue - Tension [PopMatters, Rolling Stone]
[2] Margo Price - Strays [PopMatters, Uncut]
[2] Mandy, Indiana - i’ve seen a way [PopMatters, Pitchfork]
[2] Gorillaz - Cracker Island [PopMatters, Louder Than War]
[2] Explosions In The Sky - End [PopMatters, Piccadilly Records]
[2] Forest Swords - Bolted [PopMatters, Piccadilly Records]
[2] The Church - The Hypnogogue [PopMatters, Fast 'n' Bulbous]
[2] Miley Cyrus - Endless Summer Vacation [PopMatters, Rolling Stone]
[2] Frankie and the Witch Fingers - Data Doom [PopMatters, Fast 'n' Bulbous]
[2] JOANNA STERNBERG - I’ve Got Me [Pitchfork, Gorilla vs Bear]
[2] Youth Lagoon - Heaven Is a Junkyard [Pitchfork, Paste]
[2] Blue Lake - Sun Arcs [Pitchfork, Paste]
[2] 파란노을 (Parannoul) - After the Magic [Pitchfork, Consequence]
[2] Purelink - Signs [Pitchfork, Crack]
[2] André 3000 - New Blue Sun [Pitchfork, Consequence]
[2] Anohni & the Johnsons - My Back Was a Bridge for You to Cross [Crack, The Line of Best Fit]
[2] DEBBY FRIDAY - GOOD LUCK [Crack, Exclaim]
[2] JONNINE - Maritz [Crack, Gorilla vs Bear]
[2] Lil Yachty - Let's Start Here. [Crack, Exclaim]
[2] Slauson Malone 1 - Excelsior [Crack, The Quietus]
[2] Nihiloxica - Source Of Denial [Crack, The Quietus]
[2] FREAK HEAT WAVES - Mondo Tempo [Crack, Gorilla vs Bear]
[2] Bdrmm - I Don't Know [The Line of Best Fit, Piccadilly Records]
[2] Corrine Bailey Rae - Black Rainbows [The Line of Best Fit, Louder Than War]
[2] Danny Brown - Quaranta [The Line of Best Fit, The Quietus]
[2] Home Is Where - the whaler [The Line of Best Fit, Exclaim]
[2] Paris Texas - MID AIR [The Line of Best Fit, Consequence]
[2] Joanna Sternberg - I've Got Me [The Line of Best Fit, Rolling Stone]
[2] KAYTRAMINÉ - KAYTRAMINÉ [The Line of Best Fit, Exclaim]
[2] Skrillex - Quest for Fire [The Line of Best Fit, Rolling Stone]
[2] TIRZAH - trip9love…??? [The Line of Best Fit, Gorilla vs Bear]
[2] Yves Tumor - Praise a Lord Who Chews But Which Does Not Consume [Consequence, Rolling Stone]
[2] Zach Bryan - Zach Bryan [Consequence, Rolling Stone]
[2] feeble little horse - Girl With Fish [Consequence, Paste]
[2] Killer Mike - Michael [Consequence, Piccadilly Records]
[2] Genesis Owusu - Struggler [Consequence, Louder Than War]
[2] Hotline TNT - Cartwheel [Consequence, Paste]
[2] Spirit Adrift - Ghost at the Gallows [Fast 'n' Bulbous, Decibel]
[2] CIVIC - Taken By Force [Fast 'n' Bulbous, Louder Than War]
[2] Protomartyr - Formal Growth In The Desert [Fast 'n' Bulbous, Piccadilly Records]
[2] Skull Practitioners - Negative Stars [Fast 'n' Bulbous, The Quietus]
[2] Squid - O Monolith [Fast 'n' Bulbous, Piccadilly Records]
[2] Panopticon - The Rime of Memory [Fast 'n' Bulbous, Decibel]
[2] The Keening - Little Bird [Fast 'n' Bulbous, Decibel]
[2] Godthrymm - Distortions [Fast 'n' Bulbous, Decibel]
[2] RVG - Brain Worms [Fast 'n' Bulbous, Louder Than War]
[2] Horrendous - Ontological Mysterium [Fast 'n' Bulbous, Decibel]
[2] Harp - Albion [Fast 'n' Bulbous, Piccadilly Records]
[2] House Of All - House Of All [Louder Than War, The Quietus]
[2] John - A Life Diagrammatic [Louder Than War, Piccadilly Records]
[2] Baxter Dury - I Thought I Was Better Than You [Louder Than War, Rough Trade]
[2] Queens Of The Stone Age - In Times New Roman [Louder Than War, Piccadilly Records]
[2] Cécile McLorin Salvant - Mélusine [Louder Than War, Mojo]
[2] ØXN - CYRM [Louder Than War, The Quietus]
[2] Gina Birch - I Play My Bass Loud [Louder Than War, Mojo]
[2] Daughter - Stereo Mind Game [Louder Than War, Rough Trade]
[2] Goat - Medicine [Louder Than War, Piccadilly Records]
[2] James Ellis Ford - The Hum [Louder Than War, The Quietus]
[2] Oneohtrix Point Never - Again [Gorilla vs Bear, Piccadilly Records]
[2] Danny Brown and JPEGMAFIA - SCARING THE HOES [Rolling Stone, Exclaim]
[2] U.S. Girls - Bless This Mess [Rolling Stone, Exclaim]
[2] The Rolling Stones - Hackney Diamonds [Rolling Stone, Uncut]
[2] The National - First Two Pages of Frankenstein [Rolling Stone, Uncut]
[2] Feist - Multitudes [Exclaim, Uncut]
[2] Colin Stetson - When We Were That What Wept For The Sea [Exclaim, The Quietus]
[2] Shame - Food For Worms [Exclaim, Piccadilly Records]
[2] The Lemon Twigs - Everything Harmony [Paste, Mojo]
[2] Robert Forster - The Candle and the Flame [Mojo, Uncut]
[2] Paul Simon - Seven Psalms [Mojo, Uncut]
[2] Arooj Aftab, Vijay Iyer & Shahzad Ismaily - Love In Exile [Mojo, Uncut]
[2] Pretenders - Relentless [Mojo, Uncut]
[2] John Cale - Mercy [Mojo, Uncut]
[2] Lisa O’Neill - All Of This Is Chance [Mojo, Uncut]
[2] Sarabeth Tucek - Joan Of All [Mojo, Uncut]
[2] Gaz Coombes - Turn The Car Around [Mojo, Piccadilly Records]
[2] Dexys - The Feminine Divine [Mojo, Uncut]
[2] Hamish Hawk - Angel Numbers [Mojo, Piccadilly Records]
[2] Blake Mills - Jelly Road [Mojo, Uncut]
[2] Baaba Maal - Being [Mojo, Uncut]
[2] Gabriels - Angels & Queens [Mojo, Piccadilly Records]
[2] Billy Valentine - Billy Valentine and The Universal Truth [Mojo, Uncut]
[2] Margo Cilker - Valley Of Heart’s Delight [Mojo, Uncut]
[2] Say She She - Silver [Mojo, Piccadilly Records]
[2] Matthew Halsall - An Ever Changing View [Uncut, Piccadilly Records]
[2] Nabihah Iqbal - Dreamer [The Quietus, Piccadilly Records]
[2] RVG - Brainworms [Rough Trade, Rough Trade]
[1] Lana Del Rey - Did You Know That There’s a Tunnel Under Ocean Blvd? [Clash]
[1] JPEGMafia and Danny Brown - Scaring The Hoes [Clash]
[1] Yazmin Lacey - Voice Notes [Clash]
[1] Yves Tumor - Praise A Lord Who Chews, But Which Does Not Consume; (Or Simply, Hot Between Worlds) [Clash]
[1] Actress - LXXXVIII [Clash]
[1] Navy Blue - Ways Of Knowing [Clash]
[1] Eartheater - Powders [Clash]
[1] Barry Can’t Swim - When Will We Land? [Clash]
[1] Ralphie Choo - SUPERNOVA [Clash]
[1] Potter Payper - Real Back In Style [Clash]
[1] Kaytranada, Aminé - Kaytraminé [Clash]
[1] Avatar - Dance Devil Dance [Metal Hammer (Readers Poll)]
[1] Katatonia - Sky Void Of Stars [Metal Hammer (Readers Poll)]
[1] Lovebites - Judgement Day [Metal Hammer (Readers Poll)]
[1] Beyond The Black - Beyond The Black [Metal Hammer (Readers Poll)]
[1] Delain - Dark Waters [Metal Hammer (Readers Poll)]
[1] Blackbriar - A Dark Euphony [Metal Hammer (Readers Poll)]
[1] Tesseract - War Of Being [Metal Hammer (Readers Poll)]
[1] The Acacia Strain - Step Into The Light [Metal Hammer (Readers Poll)]
[1] Overkill - Scorched [Metal Hammer (Readers Poll)]
[1] Sylosis - A Sign Of Things To Come [Metal Hammer (Readers Poll)]
[1] The Acacia Strain - Failure Will Follow [Metal Hammer (Readers Poll)]
[1] Hellripper - Warlocks Grim & Withered Hags [Metal Hammer (Readers Poll)]
[1] Bury Tomorrow - The Seventh Sun [Metal Hammer (Readers Poll)]
[1] Myrkur - Spine [Metal Hammer (Readers Poll)]
[1] Hanabie - Reborn Superstar! [Metal Hammer (Readers Poll)]
[1] Crypta - Shades Of Sorrow [Metal Hammer (Readers Poll)]
[1] KK's Priest - The Sinner Rides Again [Metal Hammer (Readers Poll)]
[1] Ne Obliviscaris - Exul [Metal Hammer (Readers Poll)]
[1] The Zenith Passage - Datalysium [Metal Hammer (Readers Poll)]
[1] Suffocation - Hymns From the Apocrypha [Metal Hammer (Readers Poll)]
[1] Mental Cruelty - Zwielicht [Metal Hammer (Readers Poll)]
[1] The Raven Age - Blood Omen [Metal Hammer (Readers Poll)]
[1] King Gizzard & The Lizard Wizard - PetroDragonic Apocalypse [Metal Hammer (Readers Poll)]
[1] Twin Temple - God Is Dead [Metal Hammer (Readers Poll)]
[1] Kvelertak - Endling [Metal Hammer (Readers Poll)]
[1] Immortal - War Against All [Metal Hammer (Readers Poll)]
[1] Danny Brown x JPEGMAFIA - SCARING THE HOES [The Fader]
[1] Neggy Gemmy - CBD Reiki Moonbeam [The Fader]
[1] Sword II - Spirit World Tour [The Fader]
[1] Peso Pluma - GÉNESIS [The Fader]
[1] brakence - hypochondriac [The Fader]
[1] DJ K - Panico No Submundo [The Fader]
[1] Evian Christ - Revanchist [The Fader]
[1] ANOHNI - My Back Was A Bridge For You To Cross [The Fader]
[1] Brevin Kim - High School Football [The Fader]
[1] Jlin - Perspective [The Fader]
[1] Diego Raposo - YO NO ERA ASÍ PERO DE AHORA EN ADELANTE, SÍ [The Fader]
[1] mark william lewis - Living [The Fader]
[1] jonatan leandoer96 - Sugar World [The Fader]
[1] Anysia Kym and Jadasea - Pressure Sensitive [The Fader]
[1] Underscores - Wallsocket [The Forty-Five]
[1] LE SSERAFIM - Unforgiven [The Forty-Five]
[1] Priya Ragu - Santhosam [The Forty-Five]
[1] Be Your Own Pet - Mommy [The Forty-Five]
[1] Jockstrap - I<3UQTINVU [The Forty-Five]
[1] LVRA - Soft Like Steel [The Forty-Five]
[1] Tkay Maidza - Sweet Justice [The Forty-Five]
[1] yeule - soft scars [The Forty-Five]
[1] Tinashe - BB/ANG3L [The Forty-Five]
[1] Laufey - Bewitched [The Forty-Five]
[1] Sofia Kourtesis - Madre [The Forty-Five]
[1] Chappell Roan - Rise And Fall Of A Midwest Princess [The Forty-Five]
[1] Biig Piig - Bubblegum [The Forty-Five]
[1] Ashnikko - WEEDKILLER [The Forty-Five]
[1] Arxx - Ride Or Die [The Forty-Five]
[1] Miya Folick - Roach [The Forty-Five]
[1] The Japanese House - In The End IT Always Does [The Forty-Five]
[1] Creeper - Sanguivore [Kerrang!]
[1] Holding Absence - The Noble Art Of Self Destruction [Kerrang!]
[1] Pupil Slicer - Blossom [Kerrang!]
[1] Avenged Sevenfold - Life Is But A Dream… [Kerrang!]
[1] Hot Milk - A CALL TO THE VOID [Kerrang!]
[1] Enter Shikari - A Kiss For The Whole World [Kerrang!]
[1] Skindred - Smile [Kerrang!]
[1] blink-182 - ONE MORE TIME… [Kerrang!]
[1] Fall Out Boy - So Much (For) Stardust [Kerrang!]
[1] Empire State Bastard - Rivers Of Heresy [Kerrang!]
[1] Bury Tomorrow - The Seventh Son [Kerrang!]
[1] The Gaslight Anthem - History Books [Kerrang!]
[1] WARGASM - Venom [Kerrang!]
[1] Taking Back Sunday - 152 [Kerrang!]
[1] Graphic Nature - a mind waiting to die [Kerrang!]
[1] You Me At Six - Truth Decay [Kerrang!]
[1] Dream Nails - Doom Loop [Kerrang!]
[1] Urne - A Feast On Sorrow [Kerrang!]
[1] Meet Me @ The Altar - Past // Present // Future [Kerrang!]
[1] Corey Taylor - CMF2 [Kerrang!]
[1] Waterparks - INTELLECTUAL PROPERTY [Kerrang!]
[1] PVRIS - EVERGREEN [Kerrang!]
[1] Pierce The Veil - The Jaws Of Life [Kerrang!]
[1] Grove Street - The Path To Righteousness [Kerrang!]
[1] V/Z - Suono Assente [Concrete Islands]
[1] The Declining Winter - Really Early, Really Late [Concrete Islands]
[1] Special Friend - Wait Until the Flames Come Rushing In [Concrete Islands]
[1] Jim O’Rourke - Hands That Bind [Concrete Islands]
[1] Chief Adjuah - Bark Out Thunder Roar Out Lightning [Concrete Islands]
[1] Lewsberg - Out and About [Concrete Islands]
[1] Gilroy Mere - Gilden Gate [Concrete Islands]
[1] Firestations - Thick Terrain [Concrete Islands]
[1] Dominique Fils-Aimé - Our Roots Run Deep [Concrete Islands]
[1] Pascal Comelade / Ramon Prats / Lee Ranaldo - Velvet Serenade [Concrete Islands]
[1] Rami Atassi - Dancing Together [Concrete Islands]
[1] John Fahey - Proofs & Refutations [Concrete Islands]
[1] Blondshell - S/T [Concrete Islands]
[1] Blotter Trax - Superconductor [Concrete Islands]
[1] Polypores - Praedormitium [Concrete Islands]
[1] Papernut Cambridge - Channel Suite [Concrete Islands]
[1] Suzy Mangion - Days Lost to Snow [Concrete Islands]
[1] Arnold Dreyblatt & The Orchestra of Excited Strings - Resolve [Concrete Islands]
[1] Tomorrow Syndicate - Higher Resolution [Concrete Islands]
[1] Nat Myers - Yellow Peril [Concrete Islands]
[1] Black Duck - S/T [Concrete Islands]
[1] Tara Clerkin Trio - On the Turning Ground [Concrete Islands]
[1] Emma Anderson - Pearlies [Concrete Islands]
[1] Sally Anne Morgan - Carrying [Concrete Islands]
[1] Jilk - Syrup House [Concrete Islands]
[1] Semispecific Ensemble - Everyone Is Making It Up [Concrete Islands]
[1] Makushin - Move into the Luminous [Concrete Islands]
[1] Star 99 - Bitch Unlimited [Rosy Overdrive]
[1] Soft on Crime - New Suite [Rosy Overdrive]
[1] Connections - Cool Change [Rosy Overdrive]
[1] Buddie - Agitator [Rosy Overdrive]
[1] Pacing - Real poetry is always about plants and birds and trees and the animals and milk and honey breathing in the pink but real life is behind a screen [Rosy Overdrive]
[1] Blues Lawyer - All in Good Time [Rosy Overdrive]
[1] Vista House - Oregon III [Rosy Overdrive]
[1] Poppy Patica - Black Cat Back Stage [Rosy Overdrive]
[1] Curling - No Guitar [Rosy Overdrive]
[1] Spirit Night - Bury the Dead [Rosy Overdrive]
[1] Whitney’s Playland - Sunset Sea Breeze [Rosy Overdrive]
[1] Ryan Davis & the Roadhouse Band - Dancing on the Edge [Rosy Overdrive]
[1] Taking Meds - Dial M for Meds [Rosy Overdrive]
[1] Washer - Improved Means to Deteriorated Ends [Rosy Overdrive]
[1] Norm Archer - Splitting the Bill [Rosy Overdrive]
[1] Coventry - Our Lady of Perpetual Health [Rosy Overdrive]
[1] Onesie - Liminal Hiss [Rosy Overdrive]
[1] Sharp Pins - Turtle Rock [Rosy Overdrive]
[1] Teenage Tom Petties - Hotbox Daydreams [Rosy Overdrive]
[1] Rust Ring - North to the Future [Rosy Overdrive]
[1] Brontez Purnell - Confirmed Bachelor [Rosy Overdrive]
[1] William Matheny - That Grand, Old Feeling [Rosy Overdrive]
[1] Shredded Sun - Each Dot and Each Line [Rosy Overdrive]
[1] Sunshine Convention - The Sunshine Convention [Rosy Overdrive]
[1] Bell and the Ringers - Bell and the Ringers [Rosy Overdrive]
[1] Annie Hart - The Weight of a Wave [Rosy Overdrive]
[1] Empty Country - II [Rosy Overdrive]
[1] Telehealth - Content Oscillator [Rosy Overdrive]
[1] Gaadge - Somewhere Down Below [Rosy Overdrive]
[1] Ther - A Horrid Whisper Echoes in a Palace of Endless Joy [Rosy Overdrive]
[1] Mo Troper - Troper Sings Brion [Rosy Overdrive]
[1] The High Water Marks - Your Next Wolf [Rosy Overdrive]
[1] Leor Miller’s Fear of Her Own Desire - Eternal Bliss Now! [Rosy Overdrive]
[1] Teenage Halloween - Till You Return [Rosy Overdrive]
[1] Interbellum - Our House Is Very Beautiful at Night [Rosy Overdrive]
[1] Diners - Domino [Rosy Overdrive]
[1] The World Famous - Totally Famous [Rosy Overdrive]
[1] Rob I. Miller - Companion Piece [Rosy Overdrive]
[1] Timeout Room - Tight-Ass Goku Pictures [Rosy Overdrive]
[1] The Bug Club - Rare Birds: Hour of Song [Rosy Overdrive]
[1] Total Downer - Caretaker [Rosy Overdrive]
[1] Fust - Genevieve [Rosy Overdrive]
[1] Nicole Yun - Matter [Rosy Overdrive]
[1] Local Drags - Mess of Everything [Rosy Overdrive]
[1] ME REX - Giant Elk [Rosy Overdrive]
[1] Tough Age - Waiting Here [Rosy Overdrive]
[1] The Pretty Flowers - A Company Sleeve [Rosy Overdrive]
[1] Subsonic Eye - All Around You [Rosy Overdrive]
[1] Parister - Here’s What You Wonder [Rosy Overdrive]
[1] Hammer No More the Fingers - Silver Zebra [Rosy Overdrive]
[1] Guided by Voices - Welshpool Frillies [Rosy Overdrive]
[1] Frog - Grog [Rosy Overdrive]
[1] The Cowboys - Sultan of Squat [Rosy Overdrive]
[1] Screaming Females - Desire Pathway [Rosy Overdrive]
[1] Noah Roth - Florida [Rosy Overdrive]
[1] Flat Worms - Witness Marks [Rosy Overdrive]
[1] Dusk - Glass Pastures [Rosy Overdrive]
[1] En Attendant Ana - Principia [Rosy Overdrive]
[1] The Smashing Times - This Sporting Life [Rosy Overdrive]
[1] Aux Caroling - Hydrogen Bonds [Rosy Overdrive]
[1] Lydia Loveless - Nothing’s Gonna Stand in My Way Again [Rosy Overdrive]
[1] Slaughter Beach, Dog - Crying, Laughing, Waving, Smiling [Rosy Overdrive]
[1] Royal Ottawa - Carcosa [Rosy Overdrive]
[1] Lonesome Joan - On North Pond [Rosy Overdrive]
[1] Worriers - Trust Your Gut [Rosy Overdrive]
[1] Tee Vee Repairmann - What’s on TV? [Rosy Overdrive]
[1] Florry - The Holey Bible [Rosy Overdrive]
[1] Helpful People - Brokenblossom Threats [Rosy Overdrive]
[1] Guided by Voices - La La Land [Rosy Overdrive]
[1] Fixtures - Hollywood Dog [Rosy Overdrive]
[1] Vulture Feather - Liminal Fields [Rosy Overdrive]
[1] Deep State - Diary of a Nobody [Rosy Overdrive]
[1] The Unknowns - East Coast Low [Rosy Overdrive]
[1] Brian Mietz - Wow! [Rosy Overdrive]
[1] Silicone Prairie - Vol. II [Rosy Overdrive]
[1] Glow in the Dark Flowers - Glow in the Dark Flowers [Rosy Overdrive]
[1] Misophone - A Floodplain Mind [Rosy Overdrive]
[1] Hurry - Don’t Look Back [Rosy Overdrive]
[1] The Hold Steady - The Price of Progress [Rosy Overdrive]
[1] Daily Worker - Autofiction [Rosy Overdrive]
[1] Patches - Scenic Route [Rosy Overdrive]
[1] Advertisement - Escorts [Rosy Overdrive]
[1] Your Heart Breaks - The Wrack Line [Rosy Overdrive]
[1] Podcasts - Podcasts [Rosy Overdrive]
[1] The Reds, Pinks & Purples - The Town That Cursed Your Name [Rosy Overdrive]
[1] Bory - Who’s a Good Boy [Rosy Overdrive]
[1] Six Flags Guy - And Nothing Did So What [Rosy Overdrive]
[1] Upchuck - Bite the Hand That Feeds [Rosy Overdrive]
[1] Living Dream - Living Dream [Rosy Overdrive]
[1] DJ Silky Smooth - I’m Glad for Life [Rosy Overdrive]
[1] Darius Jones - fLuXkit Vancouver (i​̶​t​̶​s suite but sacred) [The Wire]
[1] Mendoza/Hoff/Revels - Echolocation [The Wire]
[1] Cassandra Miller - Traveller Song/Thanksong [The Wire]
[1] Aksak Maboul - Une Aventure De VV (Songspiel) [The Wire]
[1] Nick Dunston - Skultura [The Wire]
[1] Sunik Kim - Potential [The Wire]
[1] AMM - Last Calls [The Wire]
[1] Dorothy Moskowitz & The United States Of Alchemy - Under An Endless Sky [The Wire]
[1] Laura Ortman - SMOKE RINGS SHIMMERS ENDLESS BLUR [The Wire]
[1] Madhuvanti Pal - The Holy Mother (Plays The Rudra Veena) [The Wire]
[1] Angel Bat Dawid - Requiem For Jazz [The Wire]
[1] Svitlana Nianio & Tom James Scott - Eye Of The Sea [The Wire]
[1] Coffin Prick - Laughing [The Wire]
[1] Škvíry & Spoje - Hotel Spojár [The Wire]
[1] Wadada Leo Smith & Orange Wave Electric - Fire Illuminations [The Wire]
[1] Liv.e - Girl In The Half-Pearl [The Wire]
[1] Ale Hop & Laura Robles - Aqua Dulce [The Wire]
[1] Jason Moran - From The Dancehall To The Battlefield [The Wire]
[1] GAIKA - Drift [The Wire]
[1] B Cool-Aid - Leather Blvd [The Wire]
[1] Natasha Barrett - Reconfiguring The Landscape [The Wire]
[1] Mayssa Jallad - Marjaa: The Battle Of The Hotels [The Wire]
[1] Position Normal - Modern And Unique [The Wire]
[1] Amy Cutler - Sister Time [The Wire]
[1] Natural Information Society - Since Time Is Gravity [The Wire]
[1] Avola - Psykor [The Wire]
[1] Alternative TV - Direct Action [The Wire]
[1] James Brandon Lewis/Red Lily Quartet - For Mahalia, With Love [The Wire]
[1] Durand Jones - Wait Till I Get Over [PopMatters]
[1] Young Fathers - Heavy Heavy (Ninja Tune) [PopMatters]
[1] Acid Arab - ٣ [PopMatters]
[1] Jason Isbell - Weathervanes [PopMatters]
[1] Altın Gün - Aşk [PopMatters]
[1] Molly Tuttle - City of Gold [PopMatters]
[1] Quantic - Dancing While Falling [PopMatters]
[1] Billy Woods/Kenny Segal - Maps [PopMatters]
[1] Lydia Loveless - Nothing’s Gonna Stand in My Way [PopMatters]
[1] Meshell Ndegeocello - The Omnichord Real Book [PopMatters]
[1] Lana Del Ray - Did You Know That There’s a Tunnel Under Ocean Blvd [PopMatters]
[1] Earl Sweatshirt and the Alchemist - VOIRE DIRE [PopMatters]
[1] Ekiti Sound - Drum Money [PopMatters]
[1] Anti-God Hand - Blight Year (American Dreams) [PopMatters]
[1] WITCH - Zango [PopMatters]
[1] Shamir - Homo Anxietatem [PopMatters]
[1] Aesop Rock - Integrated Tech Solutions [PopMatters]
[1] Sam Wilkes - Driving [PopMatters]
[1] Chris Stapleton - Higher [PopMatters]
[1] James Blake - Playing Robots Into Heaven [PopMatters]
[1] Prins Emanuel - Diagonal Musik II [PopMatters]
[1] Maisie Peters - The Good Witch [PopMatters]
[1] Blonde Redhead - Sit Down for Dinner [PopMatters]
[1] Pink - Trustfall [PopMatters]
[1] Faten Kanaan - Afterpoem [PopMatters]
[1] Iris DeMent - Workin’ on a World [PopMatters]
[1] M83 - Fantasy [PopMatters]
[1] The New Pornographers - Continue As a Guest [PopMatters]
[1] Hayden Pedigo - The Happiest Times I Ever Ignored [PopMatters]
[1] billy woods / Kenny Segal - Maps [Pitchfork]
[1] Arooj Aftab / Vijay Iyer / Shahzad Ismaily - Love in Exile [Pitchfork]
[1] Ice Spice - Like..? EP [Pitchfork]
[1] Pangaea - Changing Channels [Pitchfork]
[1] Jim Legxacy - Homeless N**** Pop Music [Crack]
[1] Bendik Giske - Bendik Giske [Crack]
[1] Liturgy - 93696 [Crack]
[1] Honour - Àlàáfíà [Crack]
[1] Vayda - Breeze [Crack]
[1] Universal Harmonies and Frequencies - Tune In [Crack]
[1] Marina Herlop - Nekkuja [Crack]
[1] Hulubalang - Bunyi Bunyi Tumbal [Crack]
[1] Speaker Music - Techxodus [Crack]
[1] AntsLive - Just a Matter of Time [Crack]
[1] Headache - The Head Hurts but the Heart Knows the Truth [Crack]
[1] Tzusing - 绿帽 Green Hat [Crack]
[1] Paul St Hilaire - Tikiman Vol. 1 [Crack]
[1] Aunty Rayzor - Viral Wreckage [Crack]
[1] Kate NV - WOW [Crack]
[1] Natural Wonder Beauty Concept - Natural Wonder Beauty Concept [Crack]
[1] Klein - Touched by an Angel [Crack]
[1] Luzmila Carpio - Inti Watana - El Retorno del Sol [Crack]
[1] Danny Brown and JPEG Mafia - Scaring the Hoes [The Line of Best Fit]
[1] VV Brown - Am I British Yet? [The Line of Best Fit]
[1] Mick Jenkins - The Patience [The Line of Best Fit]
[1] Mandy Indiana - I've Seen A Way [The Line of Best Fit]
[1] J Hus - Beautiful and Brutal Yard [The Line of Best Fit]
[1] Japanese House - In the End It Always Does [The Line of Best Fit]
[1] HMLTD - The Worm [The Line of Best Fit]
[1] Hinako Omori - stillness, softness... [The Line of Best Fit]
[1] Hannah Diamond - Perfect Picture [The Line of Best Fit]
[1] Vagabon - Sorry I Haven’t Called [The Line of Best Fit]
[1] McKinley Dixon - Beloved! Paradise! Jazz? [Consequence]
[1] Poison Ruïn - Härvest [Consequence]
[1] Agust D - D-DAY [Consequence]
[1] Earl Sweatshirt & The Alchemist - Voir Dire [Consequence]
[1] Arooj Aftab, Vijay Iyer, & Shahzad Ismaily - Love in Exile [Consequence]
[1] Margaret Glaspy - Echo the Diamond [Consequence]
[1] Sprain - The Lamb as Effigy or Three Hundred and Fifty XOXOXOS for a Spark Union with My Darling Divine [Consequence]
[1] Deeper - Careful! [Consequence]
[1] Crosses - Goodnight, God Bless, I Love U, Delete. [Revolver]
[1] Spiritbox - The Fear of Fear [Revolver]
[1] Better Lovers - God Made Me an Animal [Revolver]
[1] Dethklok - Dethalbum IV [Revolver]
[1] Scowl - Psychic Dance Routine [Revolver]
[1] Queens of the Stone Age - In Times New Roman... [Revolver]
[1] Callous Daoboys - God Smiles Upon the Callous Daoboys [Revolver]
[1] Fuming Mouth - Last Day of Sun [Revolver]
[1] Jesus Piece - ...So Alone [Revolver]
[1] 3TEETH - EndEx [Revolver]
[1] Harm's Way - Common Suffering [Revolver]
[1] In This Moment - GODMODE [Revolver]
[1] Kim Dracula - A Gradual Decline in Morale [Revolver]
[1] Ghost - Phantomime [Revolver]
[1] Estee Nack - Nacksaw Jim Duggan [Cabbages]
[1] SKECH185 & Jeff Markey - He Left Nothing For The Swim Back [Cabbages]
[1] H31R - HeadSpace [Cabbages]
[1] Conway The Machine - WON'T HE DO IT [Cabbages]
[1] Fat Tony & Taydex - I Will Make A Baby In This Damn Economy [Cabbages]
[1] B. Cool-Aid - Leather Blvd. [Cabbages]
[1] Jay Worthy - Kamaiyah & Harry Fraud, THE AM3RICAN DREAM [Cabbages]
[1] Fatboi Sharif & Steel Tipped Dove - Decay [Cabbages]
[1] Stik Figa & DJ Sean P - Pookey [Cabbages]
[1] Westside Gunn - And Then You Pray For Me [Cabbages]
[1] Nappy Nina - Mourning Due [Cabbages]
[1] Open Mike Eagle - another triumph of ghetto engineering [Cabbages]
[1] Larry June & The Alchemist - The Great Escape [Cabbages]
[1] Mach-Hommy Feat. Tha God Fahim - Notorious Dump Legends Vol. 2 [Cabbages]
[1] Hemlock Ernst & Height Keech - The Fall Collection [Cabbages]
[1] CJ Fly & Stoic - PIRANHA [Cabbages]
[1] AJ Suede & Televangel - Parthian Shots [Cabbages]
[1] Kari Faux - REAL B*TCHES DON'T DIE! [Cabbages]
[1] BoriRock & Grubby Pawz - WAVY BULLET [Cabbages]
[1] DijahSB - The Flower That Knew [Cabbages]
[1] YL - Don't Feed The Pigeons [Cabbages]
[1] Blockhead - The Aux [Cabbages]
[1] kuya - Tales From Ophir: Moros Y Cristianos [Cabbages]
[1] Al.Divino - SHEET MUSIC, Vol. 1000 [Cabbages]
[1] Large Plants - The Thorn [Fast 'n' Bulbous]
[1] Graveyard - 6 [Fast 'n' Bulbous]
[1] Body Type - Expired Candy [Fast 'n' Bulbous]
[1] Blood Ceremony - The Old Ways Remain [Fast 'n' Bulbous]
[1] Royal Thunder - Rebuilding the Mountain [Fast 'n' Bulbous]
[1] Lucid Sins - Dancing in the Dark [Fast 'n' Bulbous]
[1] Spidergawd - VII [Fast 'n' Bulbous]
[1] Geese - 3D Country [Fast 'n' Bulbous]
[1] The Fierce & The Dead - News From the Invisible World [Fast 'n' Bulbous]
[1] Hollow Hand - Your Own Adventure [Fast 'n' Bulbous]
[1] Emile - Spirit [Fast 'n' Bulbous]
[1] David Eugene Edwards - Hyacinth [Fast 'n' Bulbous]
[1] Motorpsycho - Yay! [Fast 'n' Bulbous]
[1] Witch Ripper - The Fight After the Fall [Fast 'n' Bulbous]
[1] Glass Hammer - Arise [Fast 'n' Bulbous]
[1] The Black Waves - Sonic Maze [Fast 'n' Bulbous]
[1] DoctoR Doom - A Shadow Called Danger [Fast 'n' Bulbous]
[1] White Canyon & The 5th Dimension - Gardeners of the Earth [Fast 'n' Bulbous]
[1] Kanaan - Downpour [Fast 'n' Bulbous]
[1] DIIE - The Right Hand of the Devil [Fast 'n' Bulbous]
[1] Black Helium - UM [Fast 'n' Bulbous]
[1] Mansion - Second Death [Fast 'n' Bulbous]
[1] REZN - Solace [Fast 'n' Bulbous]
[1] Rose City Band - Garden Party [Fast 'n' Bulbous]
[1] Sorcerer - Reign of the Reaper [Fast 'n' Bulbous]
[1] Dream Wife - Social Lubrication [Fast 'n' Bulbous]
[1] Egyptian Blue - A Living Commodity [Fast 'n' Bulbous]
[1] Druid Fluids - Then, Now, Again & Again [Fast 'n' Bulbous]
[1] Wytch Hazel - IV: Sacrament [Fast 'n' Bulbous]
[1] Legendry - Time Immortal Wept [Fast 'n' Bulbous]
[1] High Spirits - Safe on the Other Side [Fast 'n' Bulbous]
[1] Narrow Head - Moments of Clarity [Fast 'n' Bulbous]
[1] Peter Gabriel - i/o [Fast 'n' Bulbous]
[1] Bas Jan - Back to the Swamp [Fast 'n' Bulbous]
[1] Cable Ties - All Her Plans [Fast 'n' Bulbous]
[1] Ghost Woman - Hindsight is 50/50 [Fast 'n' Bulbous]
[1] Do Nothing - Snake Sideways [Fast 'n' Bulbous]
[1] Spiritual Cramp - Spiritual Cramp [Fast 'n' Bulbous]
[1] The Heavy Minds - Beyond Gloom [Fast 'n' Bulbous]
[1] Howling Giant - Glass Future [Fast 'n' Bulbous]
[1] Kanaan - Diversions Vol. 2: Enter the Astral Plane [Fast 'n' Bulbous]
[1] Futuropaco - Fortezza di Vetro Vol. 1 [Fast 'n' Bulbous]
[1] Church Of Misery - Born Under A Mad Sign [Fast 'n' Bulbous]
[1] Flyying Colours - You Never Know [Fast 'n' Bulbous]
[1] Giöbia - Acid Disorder [Fast 'n' Bulbous]
[1] Restless Spirit - Afterimage [Fast 'n' Bulbous]
[1] Edena Gardens - Agar [Fast 'n' Bulbous]
[1] Edena Gardens - Dens [Fast 'n' Bulbous]
[1] Haunt - Golden Arm [Fast 'n' Bulbous]
[1] Rival Sons - Darkfighter [Fast 'n' Bulbous]
[1] Witchskull - The Serpent Tide [Fast 'n' Bulbous]
[1] Holy Wave - Five of Cups [Fast 'n' Bulbous]
[1] The Bright Light Social Hour - Emergency Leisure [Fast 'n' Bulbous]
[1] Bush Tetras - They Live in My Head [Fast 'n' Bulbous]
[1] Nemegata - Voces [Fast 'n' Bulbous]
[1] Night Beats - Rajan [Fast 'n' Bulbous]
[1] Lamp of the Universe - Kaleidoscope Mind [Fast 'n' Bulbous]
[1] Vanishing Kids - Miracle of Death [Fast 'n' Bulbous]
[1] Travo - Astromorph God [Fast 'n' Bulbous]
[1] Raze Regal & White Denim Inc - Raze Regal & White Denim Inc [Fast 'n' Bulbous]
[1] Maggot Heart - Hunger [Fast 'n' Bulbous]
[1] Me And My Kites - A Safe Trail [Fast 'n' Bulbous]
[1] Teke::Teke - Hagata [Fast 'n' Bulbous]
[1] The Murder Capital - Gigi’s Recovery [Fast 'n' Bulbous]
[1] Blood Lightning - Blood Lightning [Fast 'n' Bulbous]
[1] Krypta - Outo laakso [Fast 'n' Bulbous]
[1] Agusa - Prima Materia [Fast 'n' Bulbous]
[1] Rain Parade - Last Rays of a Dying Sun [Fast 'n' Bulbous]
[1] Demons My Friends - Demons Seem to Gather [Fast 'n' Bulbous]
[1] Another Heaven - IV: Heaven Sent [Fast 'n' Bulbous]
[1] The Loving Paupers - Ladders [Fast 'n' Bulbous]
[1] The Routes - Reverberation Addict [Fast 'n' Bulbous]
[1] Amplifier - Hologram [Fast 'n' Bulbous]
[1] Crown Lands - Fearless [Fast 'n' Bulbous]
[1] Dopelord - Songs for Satan [Fast 'n' Bulbous]
[1] Ritual King - The Infinite Mirror [Fast 'n' Bulbous]
[1] Lol Tolhurst x Budgie x Jacknife Lee - Los Angeles [Louder Than War]
[1] Mudhoney - Plastic Eternity [Louder Than War]
[1] Evil Blizzard - Rotting In The Belly Of The Whale [Louder Than War]
[1] Teenage Waitress - Your Cuckoo [Louder Than War]
[1] Swansea Sound - Twentieth Century [Louder Than War]
[1] Rhoda Dakar - Version Girl [Louder Than War]
[1] Ren - Sick Boi [Louder Than War]
[1] Frankie & The Witch Fingers - Data Doom [Louder Than War]
[1] The Shits - You’re A Mess [Louder Than War]
[1] Wreckless Eric - Leisureland [Louder Than War]
[1] The Damned - Darkadelic [Louder Than War]
[1] Crime And The City Solution - the Killer [Louder Than War]
[1] Def Robot - Existential Boredom [Louder Than War]
[1] King Gizzard & The Lizard Wizard - The Silver Cord [Louder Than War]
[1] Chris Broderick & Stuart Turner with Vicky Price - And One Red Mitten [Louder Than War]
[1] Zero Again - A Deep Appreciation Of Suffering [Louder Than War]
[1] It It Anita - Mouche [Louder Than War]
[1] The Psychotic Monks - Pink Colour Surgery [Louder Than War]
[1] The Answer - Sundowners [Louder Than War]
[1] Bruise Control - Useless For Something [Louder Than War]
[1] Hawkwind - The Future Never Waits [Louder Than War]
[1] Battery Operated Orchestra - Compulsory Games [Louder Than War]
[1] HiFi Sean & David Almont - Happy Ending [Louder Than War]
[1] Primitive Knot - Undying Lands [Louder Than War]
[1] Seán Berna - An Evening At Macri Park [Louder Than War]
[1] Cran - Natë [Louder Than War]
[1] Feral Five - Truth Is The New Gold [Louder Than War]
[1] Baskery - V. End Of The Bloodline [Louder Than War]
[1] Morgan And The Organ Donors - M.O.D.S. [Louder Than War]
[1] Emma Tricca - Aspirin Sun [Louder Than War]
[1] Gnarface - This Aint Art [Louder Than War]
[1] Jim Jones All Stars - Ain’t No Peril [Louder Than War]
[1] The Jesus & Mary Chain - Sunset 666 [Louder Than War]
[1] Vipertime - Arise [Louder Than War]
[1] Ist Ist - Protagonists [Louder Than War]
[1] Blue Orchids - Magpie Heights [Louder Than War]
[1] Saint Martyn - The Day God Died [Louder Than War]
[1] CHUM - Metaphysical [Louder Than War]
[1] Bad//Dreems - Hoo Ha [Louder Than War]
[1] Morlocks - Praise The Iconoclast [Louder Than War]
[1] Mone - Darling, Thief [Louder Than War]
[1] Micko & The Mellotronics - Le Vice Angliais [Louder Than War]
[1] The Shed Project - Our Fear Is Their Power [Louder Than War]
[1] Orbital - Optical Delusion [Louder Than War]
[1] The Dirt - Agitator [Louder Than War]
[1] Marlody - I’m Not Sure At All [Louder Than War]
[1] Private Function - 370HSSV 0773H [Louder Than War]
[1] The Nightingales - Live In Balsall Heath [Louder Than War]
[1] Dexys - The Feminine Devine [Louder Than War]
[1] Scrimshire - Paroxysm [Louder Than War]
[1] Princess Goes - Come Of Age [Louder Than War]
[1] Pill Fangs - PF7 [Louder Than War]
[1] Band Of Holy Joy - Fated Beautiful Mistakes [Louder Than War]
[1] The Astronauts - LP [Louder Than War]
[1] POD - The Earth’s Rotation [Louder Than War]
[1] DJ Shadow - Action Adventure [Louder Than War]
[1] Christine & The Queens - Paranoïa, Angels, True Love [Louder Than War]
[1] Keeley - Floating Above Everything Else [Louder Than War]
[1] Vince Clarke - Songs Of Silence [Louder Than War]
[1] Dirt Byrds - Standing In Line [Louder Than War]
[1] High Span - The High Span [Louder Than War]
[1] BILLY WOODS + KENNY SEGAL - Maps [Gorilla vs Bear]
[1] LAURA GROVES - Radio Red [Gorilla vs Bear]
[1] HELENA DELAND - Goodnight Summerland [Gorilla vs Bear]
[1] ANDRE 3000 - New Blue Sun [Gorilla vs Bear]
[1] MEAGRE MARTIN - Gut Punch [Gorilla vs Bear]
[1] JAM CITY - Jam City Presents EFM [Gorilla vs Bear]
[1] BEING DEAD - When Horses Would Run [Gorilla vs Bear]
[1] JPEGMAFIA x DANNY BROWN - SCARING THE HOES [Gorilla vs Bear]
[1] BAR ITALIA - Tracey Denim + The Twits [Gorilla vs Bear]
[1] TUJIKO NORIKO - Crepuscule I & II [Gorilla vs Bear]
[1] MARINA ZISPIN - Life and Death - The Five Chandeliers of the Funereal Exorcisms [Gorilla vs Bear]
[1] RAINY MILLER x SPACE AFRIKA - A Grisaille Wedding [Gorilla vs Bear]
[1] MANDAWORLD - For Emotional Use Only [Gorilla vs Bear]
[1] VOICE ACTOR - Fake Sleep [Gorilla vs Bear]
[1] JESS WILLIAMSON - Time Ain't Accidental [Gorilla vs Bear]
[1] CARLENE - Looking Out My Window [Gorilla vs Bear]
[1] OLIVER COATES - Aftersun OST [Gorilla vs Bear]
[1] JOUSKA - Suddenly My Mind is Blank [Gorilla vs Bear]
[1] LISEL - Patterns For Auto-Tuned Voices And Delay [Gorilla vs Bear]
[1] JOANNE ROBERTSON - Blue Car [Gorilla vs Bear]
[1] ISOLA - LP1 [Gorilla vs Bear]
[1] SUN JUNE - Bad Dream Jaguar [Gorilla vs Bear]
[1] JOHN GLACIER x SURF GANG - JGSG [Gorilla vs Bear]
[1] BUZZY LEE - Internal Affairs [Gorilla vs Bear]
[1] ANDREA - Due in Color [Gorilla vs Bear]
[1] SOCCER COMMITTEE - ❤️ / Lamb [Gorilla vs Bear]
[1] SHABAZZ PALACES - Robed in Rareness [Gorilla vs Bear]
[1] CHUQUIMAMANI-CONDORI - DJ E [Gorilla vs Bear]
[1] ABBEY BLACKWELL - My Maze [Gorilla vs Bear]
[1] NOIA - gisela [Gorilla vs Bear]
[1] TDJ - SPF INFINI3 [Gorilla vs Bear]
[1] Tainy - Data [Rolling Stone]
[1] Lil Yachty - Let's Start Here [Rolling Stone]
[1] Chappell Roan - The Rise and Fall of a Midwest Princess [Rolling Stone]
[1] Karol G - Mañana Será Bonito [Rolling Stone]
[1] Becky G - Esquinas [Rolling Stone]
[1] Young Nudy - Gumbo [Rolling Stone]
[1] Kesha - Gag Order [Rolling Stone]
[1] Caroline Polacheck - Desire, I Want to Turn Into You [Rolling Stone]
[1] Bad Bunny - Nadie Sabe Lo Que Va a Pasar Mañana [Rolling Stone]
[1] Drake - For All the Dogs [Rolling Stone]
[1] Kaytranada and Aminé - Kaytraminé [Rolling Stone]
[1] Samory I - Strength [Rolling Stone]
[1] Megan Moroney - Lucky [Rolling Stone]
[1] Jenny Lewis - Joy'All [Rolling Stone]
[1] Gunna - A Gift and a Curse [Rolling Stone]
[1] Dominic Fike - Sunburn [Rolling Stone]
[1] Jordan Ward - Forward [Rolling Stone]
[1] Reneé Rapp - Snow Angel [Rolling Stone]
[1] Melanie Martinez - Portals [Rolling Stone]
[1] Peso Pluma - Genesis [Rolling Stone]
[1] Bonny Doon - Let There Be Music [Rolling Stone]
[1] Earl Sweatshirt and Alchemist - Voir Dire [Rolling Stone]
[1] Hozier - Unreal Unearth [Rolling Stone]
[1] Gracie Abrams - Good Riddance [Rolling Stone]
[1] Mr. Eazi - The Evil Genius [Rolling Stone]
[1] PinkPantheress - Heaven Knows [Rolling Stone]
[1] Grupo Frontera - El Comienzo [Rolling Stone]
[1] Various Artists - Barbie the Album [Rolling Stone]
[1] Suga - D-DAY [Rolling Stone]
[1] Burna Boy - I Told Them … [Rolling Stone]
[1] Palehound - Eye on the Bat [Rolling Stone]
[1] Bebe Rexha - Bebe [Rolling Stone]
[1] Gale - Lo Que No Te Dije [Rolling Stone]
[1] Low Cut Connie - Art Dealers [Rolling Stone]
[1] Diego Raposo - Yo No Era Así, Pero de Ahora en Adelante, Sí [Rolling Stone]
[1] Adekunle Gold - Tequila Ever After [Rolling Stone]
[1] Lucinda Williams - Stories From a Rock N Roll Heart [Rolling Stone]
[1] DannyLux - DLux [Rolling Stone]
[1] Larry June and the Alchemist - The Great Escape [Rolling Stone]
[1] Nicki Nicole - Alma [Rolling Stone]
[1] Rae Sremmurd - Sremm 4 Life [Rolling Stone]
[1] Crosslegged - Another Blue [Rolling Stone]
[1] Kelsea Ballerini - Rolling Up the Welcome Mat (For Good) [Rolling Stone]
[1] Zoon - Bekka Ma'iingan [Exclaim]
[1] MSPAINT - Post-American [Exclaim]
[1] Home Front - Games of Power [Exclaim]
[1] Dizzy - Dizzy [Exclaim]
[1] TOBi - PANIC [Exclaim]
[1] Jeff Rosenstock - HELLMODE [Exclaim]
[1] myst milano. - Beyond the Uncanny Valley [Exclaim]
[1] Agriculture - Agriculture [Exclaim]
[1] BIG|BRAVE - nature morte [Exclaim]
[1] The HIRS Collective - We're Still Here [Exclaim]
[1] Jayda G - Guy [Exclaim]
[1] Harrison - Birds, Bees, the Clouds & the Trees [Exclaim]
[1] jaimie branch - Fly or Die Fly or Die Fly or Die (World War) [Paste]
[1] Ragana - Desolation’s Flower [Paste]
[1] Cut Worms - Cut Worms [Paste]
[1] Titanic - Vidrio [Paste]
[1] Squirrel Flower - Tomorrow’s Fire [Paste]
[1] Kate Davis - Fish Bowl [Paste]
[1] Wayfarer - American Gothic [Decibel]
[1] Lamp of Murmuur - Saturnian Bloodstorm [Decibel]
[1] Frozen Soul - Glacial Domination [Decibel]
[1] Thantifaxath - Hive Mind Narcosis [Decibel]
[1] Enforced - War Remains [Decibel]
[1] The Night Eternal - Fatale [Decibel]
[1] Tribunal - The Weight of Remembrance [Decibel]
[1] Cruciamentum - Obsidian Refractions [Decibel]
[1] Autopsy - Ashes, Organs, Blood and Crypts [Decibel]
[1] Mizmor - Prosaic [Decibel]
[1] Rid of Me - Access to the Lonely [Decibel]
[1] Krieg - Ruiner [Decibel]
[1] Great Falls - Objects Without Pain [Decibel]
[1] Filth Is Eternal - Find Out [Decibel]
[1] Incantation - Unholy Deification [Decibel]
[1] Night Demon - Outsider [Decibel]
[1] Kruelty - Untopia [Decibel]
[1] Smoulder - Violent Creed of Vengeance [Decibel]
[1] Will Haven - VII [Decibel]
[1] Krigsgrav - Fires in the Fall [Decibel]
[1] Final Gasp - Mourning Moon [Decibel]
[1] Circle of Ouroborus - Lumi Vaientaa Kysymykset [Decibel]
[1] Witching - Incendium [Decibel]
[1] Fires in the Distance - Air Not Meant for Us [Decibel]
[1] Street Tombs - Reclusive Decay [Decibel]
[1] Kommodus - Wreath of Bleeding Snowfall [Decibel]
[1] Dødheimsgard - Black Medium Current [Decibel]
[1] Noel Gallagher’s High Flying Birds - Council Skies [Mojo]
[1] Billy Nomates - CACTI [Mojo]
[1] Bill Orcutt - Jump On It [Mojo]
[1] Lloyd Cole - On Pain [Mojo]
[1] Kassa Overall - Animals [Mojo]
[1] Ian Hunter - Defiance, Pt. 1 [Mojo]
[1] Susanne Sundfør - blómi [Mojo]
[1] Rickie Lee Jones - Pieces of Treasure [Mojo]
[1] Jana Horn - The Window Is The Dream [Mojo]
[1] Rogê - Curyman [Mojo]
[1] Róisín Murphy - Hit Parade [Mojo]
[1] Iggy Pop - EVERY LOSER [Mojo]
[1] Public Image Ltd. - End of World [Mojo]
[1] Jonathan Wilson - Eat the Worm [Mojo]
[1] Alogte Oho & His Sounds of Joy - O Yinne! [Mojo]
[1] Edgar Jones - Reflections of a Soul Dimension [Mojo]
[1] Robert Finley - Black Bayou [Mojo]
[1] Hiss Golden Messenger - Jump For Joy [Uncut]
[1] Sam Burton - Dear Departed [Uncut]
[1] Kassi Valazza - Kassi Valazza Knows Nothing [Uncut]
[1] Califone - villagers [Uncut]
[1] Israel Nash - Ozarker [Uncut]
[1] Unknown Mortal Orchestra - V [Uncut]
[1] Modern Nature - No Fixed Point In Space [Uncut]
[1] Cian Nugent - She Brings Me Back To The Land Of The Living [Uncut]
[1] Allison Russell - The Returner [Uncut]
[1] Craven Faults - Standers [Uncut]
[1] London Brew - London Brew [Uncut]
[1] Tinariwen - Amatssou [Uncut]
[1] ? - ? [Uncut]
[1] Mary Lattimore - Goodbye, Hotel Arkada [Uncut]
[1] Setting - Shone a Rainbow Light On [Uncut]
[1] Deer Tick - Emotional Contracts [Uncut]
[1] Dot Allison - Consciousology [Uncut]
[1] Jim O’Rourke - Hands That Bind (Original Motion Picture Soundtrack) [Uncut]
[1] Bonnie ‘Prince’ Billy - Keeping Secrets Will Destroy You [Uncut]
[1] Alabaster DePlume - Come With Fierce Grace [Uncut]
[1] Steve Gunn & David Moore - Let the Moon Be a Planet [Uncut]
[1] Jim Ghedi And Toby Hay - Jim Ghedi and Toby Hay [Uncut]
[1] Elijah McLaughlin Ensemble - Elijah McLaughlin Ensemble III [Uncut]
[1] Teeth Of The Sea - Hive [The Quietus]
[1] La Baracande - La Baracande [The Quietus]
[1] Musta Huone - Valosaasteen sekaan [The Quietus]
[1] Abstract Concrete - Abstract Concrete [The Quietus]
[1] Shit And Shine - 2222 And Airport [The Quietus]
[1] The Inward Circles - Before We Lie Down In Darknesse [The Quietus]
[1] Brìghde Chaimbeul - Carry Them With Us [The Quietus]
[1] Rắn Cạp Đuôi Collective - *1 [The Quietus]
[1] PoiL Ueda - PoiL Ueda [The Quietus]
[1] La Tène - Ecorcha / Taillée [The Quietus]
[1] Surgeon - Crash Recoil [The Quietus]
[1] Babybaby_explores - Food Near Me, Weather Tomorrow [The Quietus]
[1] Lost Girls - Selvutsletter [The Quietus]
[1] Annelies Monseré - Mares [The Quietus]
[1] Gazelle Twin - Black Dog [The Quietus]
[1] Moundabout - An Cnoc Mór [The Quietus]
[1] MC Yallah - Yallah Beibe [The Quietus]
[1] Lunch Money Life - The God Phone [The Quietus]
[1] Lisa O'Neill - All Of This Is Chance [The Quietus]
[1] UKAEA - Birds Catching Fire In The Sky [The Quietus]
[1] Hey Colossus - In Blood [The Quietus]
[1] Alexander Tucker & Keith Collins - Fifth Continent [The Quietus]
[1] Nuovo Testamento - Love Lines [The Quietus]
[1] Babau - Flatland Explorations Vol. 2 [The Quietus]
[1] EP/64-63 - EP/64-63 [The Quietus]
[1] JAAW - Supercluster [The Quietus]
[1] Polobi & The Gwo Ka Masters - Abri Cyclonique [The Quietus]
[1] Enola Gay - Casement [The Quietus]
[1] Bell Witch - Future's Shadow Part 1: The Clandestine Gate [The Quietus]
[1] O Yama O - Galo [The Quietus]
[1] KMRU - Dissolution Grip [The Quietus]
[1] Mendoza Hoff Revels - Echolocation [The Quietus]
[1] a.P.A.t.T. - We [The Quietus]
[1] Natalia Beylis - Mermaids [The Quietus]
[1] Cassandra Miller - Traveller Song / Thanksong [The Quietus]
[1] Sourdurent - L'Herbe De Détourne [The Quietus]
[1] Flesh & The Dream - Choose Mortality [The Quietus]
[1] TORPOR - Abscission [The Quietus]
[1] Årabrot - Of Darkness And Light [The Quietus]
[1] Yfory - Yfory [The Quietus]
[1] Synthfreq - Vol. 1 [The Quietus]
[1] One More Grain - Modern Music [The Quietus]
[1] Nicky Wire - Intimism [The Quietus]
[1] Jellyskin - In Brine [The Quietus]
[1] Kevin Richard Martin - Black [The Quietus]
[1] Yossari Baby - Inferiority Complex [The Quietus]
[1] Zhao Cong - 55355 [The Quietus]
[1] Stephen O'Malley & Anthony Pateras - Sept duos pour guitare acoustique & piano préparé [The Quietus]
[1] Spirit Possession - Of The Sign… [The Quietus]
[1] KASAI - J/P/N [The Quietus]
[1] Anjimile - The King [The Quietus]
[1] Moussa Tchingou - Tamiditine [The Quietus]
[1] DeVon Russell Gray / Nathan Hanson / Davu Seru - We Sick [The Quietus]
[1] MXLX - Saint [The Quietus]
[1] Maxo - Even God Has A Sense Of Humor [The Quietus]
[1] Dodo Resurrection II - A Treatise On Ceremonial Magic [The Quietus]
[1] The Stargazer's Assistant - Fire Worshipper [The Quietus]
[1] Rezzett - Meant Like This [The Quietus]
[1] John Zorn - Homenaje A Remedios Varo [The Quietus]
[1] Oozing Wound - We Cater To Cowards [The Quietus]
[1] Call Super - Eulo Cramps [The Quietus]
[1] Catatonic Suns - Catatonic Suns [Piccadilly Records]
[1] Jalen Ngonda - Come Around And Love Me [Piccadilly Records]
[1] JIM - Love Makes Magic [Piccadilly Records]
[1] Eyes Of Others - Eyes Of Others [Piccadilly Records]
[1] Little Simz - NO THANK YOU [Piccadilly Records]
[1] The Murder Capital - Gigi's Recovery [Piccadilly Records]
[1] The Chemical Brothers - For That Beautiful Feeling [Piccadilly Records]
[1] Co-Pilot - Rotate [Piccadilly Records]
[1] Willie J Healey - Bunny [Piccadilly Records]
[1] Pale Blue Eyes - This House [Piccadilly Records]
[1] The National - Laugh Track [Piccadilly Records]
[1] Hania Rani - Ghosts [Piccadilly Records]
[1] Cate Brooks - Easel Studies [Piccadilly Records]
[1] Chappaqua Wrestling - Plus Ultra [Piccadilly Records]
[1] Greg Foat & Gigi Masin - Dolphin [Piccadilly Records]
[1] Woods - Perennial [Piccadilly Records]
[1] GoGo Penguin - Everything Is Going To Be Okay [Piccadilly Records]
[1] Deathcrash - Less [Piccadilly Records]
[1] 79.5 - 79.5 [Piccadilly Records]
[1] Cloth - Secret Measure [Piccadilly Records]
[1] Emma Anderson (Lush) - Pearlies [Piccadilly Records]
[1] A. Savage - Several Songs About Fire [Piccadilly Records]
[1] A Certain Ratio - 1982 [Piccadilly Records]
[1] Lost Under Heaven - Something Is Announced By Your Life! [Piccadilly Records]
[1] Sans Merit - Early Grave [Piccadilly Records]
[1] Lorelle Meets The Obsolete - Datura [Piccadilly Records]
[1] Bar Italia - The Twits [Piccadilly Records]
[1] Coastlines - Coastlines 2 [Piccadilly Records]
[1] Das Koolies - DK.01 [Piccadilly Records]
[1] Death And Vanilla - Flicker [Piccadilly Records]
[1] Ladytron - Time's Arrow [Piccadilly Records]
[1] Rozi Plain - Prize [Piccadilly Records]
[1] Sampa The Great - As Above, So Below [Piccadilly Records]
[1] Wild Nothing - Hold [Piccadilly Records]
[1] Public Service Broadcasting - This New Noise [Piccadilly Records]
[1] King Creosote - I DES [Piccadilly Records]
[1] Sigur Rós - ÁTTA [Piccadilly Records]
[1] Afflecks Palace - The Only Light In This Tunnel Is The Oncoming Train [Piccadilly Records]
[1] Alison Goldfrapp - The Love Invention [Piccadilly Records]
[1] Anna B Savage - In|Flux [Piccadilly Records]
[1] Beirut - Hadsel [Piccadilly Records]
[1] Christine And The Queens - PARANOiA, ANGELS, TRUE LOVE [Piccadilly Records]
[1] Earl Sweatshirt - SICK! [Piccadilly Records]
[1] Föllakzoid - V [Piccadilly Records]
[1] Georgia - Euphoric [Piccadilly Records]
[1] Public Image Ltd - End Of World [Piccadilly Records]
[1] Chip Wickham - Love & Life [Piccadilly Records]
[1] Pip Blom - Bobbie [Piccadilly Records]
[1] Lankum - Lankum [Rough Trade]
[1] Altin Gün - Ask [Rough Trade]
[1] Black Pumas - Chronicles of a Diamond [Rough Trade]
[1] Durand Jones - Wait Til I Get Over [Rough Trade]
```

[@hubgit]: https://github.com/hubgit
